pub struct ConnectionChannels<F> {
pub queues: PushQueues<F>,
pub handle: PushHandle<F>,
}Expand description
Bundles push queues with their shared handle for actor construction.
Fields
queues: PushQueues<F>Receivers for high- and low-priority frames consumed by the actor.
handle: PushHandle<F>Handle cloned by producers to enqueue frames into the shared queues.
Implementations
Sourceimpl<F> ConnectionChannels<F>
impl<F> ConnectionChannels<F>
Sourcepub fn new(queues: PushQueues<F>, handle: PushHandle<F>) -> Self
pub fn new(queues: PushQueues<F>, handle: PushHandle<F>) -> Self
Create a new bundle of push queues and their associated handle.