Module server

Module server 

Tokio-based server for WireframeApp instances.

WireframeServer spawns worker tasks to accept TCP connections and can decode an optional preamble before handing the stream to the application.

Re-exports

pub use error::ServerError;

Modules

binding
Listener binding for WireframeServer.
error
Errors raised by super::WireframeServer operations.
preamble
Preamble configuration for WireframeServer.

Structs

BackoffConfig
Re-exported configuration types for server backoff behavior. Configuration for exponential back-off timing in the accept loop.
Bound
Marker indicating the server is bound to a TCP listener.
Unbound
Marker indicating the server has not yet bound a listener.
WireframeServer
Tokio-based server for WireframeApp instances.

Traits

AppFactory
Factory trait for building WireframeApp instances used by the server.
FactoryResult
Convert a factory output into a Result for a WireframeApp.
PreambleSuccessHandler
Handler invoked when a connection preamble decodes successfully.
ServerState
Trait implemented by Unbound and Bound to model binding typestate.

Type Aliases

PreambleFailure
Handler invoked when decoding a connection preamble fails.
PreambleHandler
PreambleSuccessHandler wrapped in Arc.